==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/USAGEMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for USAGEMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="USAGEMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}PROFILEID"/>
 *         &lt;/choice>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USAGEUOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USAGEMETERID_Type", propOrder = {
    "assetid",
    "positionid",
    "systemid",
    "locationid",
    "profileid",
    "usageuomid"
})
public class USAGEMETERID_Type {

    @XmlElement(name = "ASSETID")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "POSITIONID")
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "SYSTEMID")
    protected EQUIPMENTID_Type systemid;
    @XmlElement(name = "LOCATIONID")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "PROFILEID")
    protected OBJECT_Type profileid;
    @XmlElement(name = "USAGEUOMID", required = true)
    protected UOMID_Type usageuomid;

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the positionid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Sets the value of the positionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Gets the value of the systemid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getSYSTEMID() {
        return systemid;
    }

    /**
     * Sets the value of the systemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setSYSTEMID(EQUIPMENTID_Type value) {
        this.systemid = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the profileid property.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getPROFILEID() {
        return profileid;
    }

    /**
     * Sets the value of the profileid property.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setPROFILEID(OBJECT_Type value) {
        this.profileid = value;
    }

    /**
     * Gets the value of the usageuomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUSAGEUOMID() {
        return usageuomid;
    }

    /**
     * Sets the value of the usageuomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUSAGEUOMID(UOMID_Type value) {
        this.usageuomid = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/USAGEMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour USAGEMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="USAGEMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}PROFILEID"/>
 *         &lt;/choice>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USAGEUOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USAGEMETERID_Type", propOrder = {
    "assetid",
    "positionid",
    "systemid",
    "locationid",
    "profileid",
    "usageuomid"
})
public class USAGEMETERID_Type {

    @XmlElement(name = "ASSETID")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "POSITIONID")
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "SYSTEMID")
    protected EQUIPMENTID_Type systemid;
    @XmlElement(name = "LOCATIONID")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "PROFILEID")
    protected OBJECT_Type profileid;
    @XmlElement(name = "USAGEUOMID", required = true)
    protected UOMID_Type usageuomid;

    /**
     * Obtient la valeur de la propriété assetid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Définit la valeur de la propriété assetid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Obtient la valeur de la propriété positionid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Définit la valeur de la propriété positionid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Obtient la valeur de la propriété systemid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getSYSTEMID() {
        return systemid;
    }

    /**
     * Définit la valeur de la propriété systemid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setSYSTEMID(EQUIPMENTID_Type value) {
        this.systemid = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété profileid.
     * 
     * @return
     *     possible object is
     *     {@link OBJECT_Type }
     *     
     */
    public OBJECT_Type getPROFILEID() {
        return profileid;
    }

    /**
     * Définit la valeur de la propriété profileid.
     * 
     * @param value
     *     allowed object is
     *     {@link OBJECT_Type }
     *     
     */
    public void setPROFILEID(OBJECT_Type value) {
        this.profileid = value;
    }

    /**
     * Obtient la valeur de la propriété usageuomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUSAGEUOMID() {
        return usageuomid;
    }

    /**
     * Définit la valeur de la propriété usageuomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUSAGEUOMID(UOMID_Type value) {
        this.usageuomid = value;
    }

}
